@@ -215,7 +215,7 @@ SEXP cdfit_binomial(SEXP X_, SEXP y_, SEXP penalty_, SEXP lambda, SEXP eps_, SEX
 	// Scan for violations in strong set
 	int violations = 0;
 	for (int j=0; j<p; j++) {
-	  if (e1[j]==0 & e2[j]==1) {
+	  if (e1[j]==0 && e2[j]==1) {
 	    z[j] = crossprod(X, s, n, j)/n;
 	    l1 = lam[l] * m[j] * alpha;
 	    if (fabs(z[j]) > l1) {
